@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Bootstrap::lib::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::Bootstrap::lib::VERSION = '0.03000000';
+  $Dist::Zilla::Plugin::Bootstrap::lib::VERSION = '0.03000100';
 }
 ## use critic;
 
@@ -24,9 +24,30 @@ sub log_debug { return 1; }
 sub plugin_name { return 'Bootstrap::lib' }
 
 
-sub dump_config { return }
+## no critic (RequireArgUnpacking)
+sub new {
+  return bless $_[1], $_[0];
+}
 
 
+sub does {
+  require Role::Tiny;
+  ## no critic (ProhibitNoWarnings)
+  { no warnings 'redefine'; *does = \&Role::Tiny::does_role }
+  goto &Role::Tiny::does_role;
+}
+
+
+## no critic (RequireArgUnpacking)
+sub meta {
+  require Moo::HandleMoose::FakeMetaClass;
+  my $class = ref( $_[0] ) || $_[0];
+  return bless { name => $class }, 'Moo::HandleMoose::FakeMetaClass';
+}
+
+
+sub dump_config { return { q{} . __PACKAGE__, $_[0]->{config} } }
+
 sub _bootstrap_dir {
   my ($dir) = @_;
   require lib;
@@ -75,6 +96,7 @@ sub _try_bootstrap_built {
   return _bootstrap_dir( $found->stringify );
 }
 
+
 sub register_component {
   my ( $plugin_class, $name, $payload, $section ) = @_;
   my $zilla  = $section->sequence->assembler->zilla;
@@ -106,6 +128,17 @@ sub register_component {
       _try_bootstrap_built( { cwd => $cwd, logger => $logger, fallback => $payload->{fallback}, distname => $distname } );
   }
 
+  push @{ $zilla->plugins }, __PACKAGE__->new(
+    {
+      config => {
+        ( exists $payload->{try_built}   ? ( try_built   => $payload->{try_built} )   : () ),
+        ( exists $payload->{fallback}    ? ( fallback    => $payload->{fallback} )    : () ),
+        ( exists $payload->{no_fallback} ? ( no_fallback => $payload->{no_fallback} ) : () ),
+
+      }
+    }
+  );
+
   return unless defined $bootstrap_path;
 
   my $root = Path::Tiny::path($bootstrap_path);
@@ -136,7 +169,7 @@ Dist::Zilla::Plugin::Bootstrap::lib - A minimal boot-strapping for Dist::Zilla P
 
 =head1 VERSION
 
-version 0.03000000
+version 0.03000100
 
 =head1 SYNOPSIS
 
@@ -155,17 +188,31 @@ the plug-in itself.
 
 =head1 METHODS
 
-=head2 log_debug
+=head2 C<log_debug>
     1;
 
-=head2 plugin_name
+=head2 C<plugin_name>
     'Bootstrap::lib'
 
-=head2 dump_config
-    sub { }
+=head2 C<new>
 
-=head2 register_component
-    sub { }
+    my $conf = __PACKAGE__->new({ config => \%arbitrary_hash});
+
+=head2 C<does>
+
+Lazily invokes Role::Tiny::does_role on demand.
+
+=head2 C<meta>
+
+Lazily creates a meta object using Moo
+
+=head2 C<dump_config>
+
+Dumps the configuration of this plugin to C<dzil>
+
+=head2 C<register_component>
+
+This is where all the real work happens.
 
 =head1 USE CASES
 
